@@ -1,4 +1,4 @@
-# $Id: AddressBook.pm,v 1.5 2001/06/08 00:24:07 muhri Exp $
+# $Id: AddressBook.pm,v 1.6 2002/05/19 06:20:46 muhri Exp $
 # -*- perl -*-
 package Pronto::AddressBook;
 use strict;
@@ -212,7 +212,13 @@ sub init_win {
 	$close->signal_connect ("clicked"    => \&des_win, $win, $data);
 	$win->signal_connect ("destroy"      => \&des_win, $win, $data);
 	$win->signal_connect ("size-request" => \&main::save_win_size, 'Address Book', $win->window);
-	ctree_click_column($ctree);
+	if ($main::prefs{'AddybookSort'}) { 
+		$ctree->set_sort_type('ascending');
+	} else {
+		$ctree->set_sort_type('descending');
+	}
+
+	$ctree->sort_recursive(undef);
 	return 1;
 }
 
