@@ -1,4 +1,4 @@
-# $Id: Compose.pm,v 1.17 2001/06/08 00:58:37 muhri Exp $
+# $Id: Compose.pm,v 1.19 2002/05/16 04:32:06 muhri Exp $
 # -*- perl -*-
 package Pronto::Compose;
 use strict;
@@ -163,7 +163,8 @@ sub init_msg_window {
 	$smoe_menu=new Gtk::Menu;
 	$msg_window->{'encryptCheck'}=new Gtk::CheckMenuItem(_("Encrypt"));
 	$msg_window->{'encryptCheck'}->set_show_toggle('1');
-	if ($main::prefs{'Encrypt'}) {$msg_window->{'encryptCheck'}->set_active(1);}
+	$msg_window->{'Encrypt'} = 0;
+	#	if ($main::prefs{'Encrypt'}) {$msg_window->{'encryptCheck'}->set_active(1);}
 	$msg_window->{'encryptCheck'}->show();
 	$smoe_menu->append($msg_window->{'encryptCheck'});
 	$msg_window->{'signCheck'}=new Gtk::CheckMenuItem(_("Sign"));
@@ -171,10 +172,10 @@ sub init_msg_window {
 	if ($main::prefs{'Sign'}) {$msg_window->{'signCheck'}->set_active(1);}
 	$msg_window->{'signCheck'}->show();
 	$smoe_menu->append($msg_window->{'signCheck'});
-	$smoe_keycheck=new Gtk::MenuItem("Key check");
-	$smoe_keycheck->signal_connect('activate', \&Pronto::Crypt::GUI::keyserver_search_window);
-	$smoe_keycheck->show();
-	$smoe_menu->append($smoe_keycheck);
+#	$smoe_keycheck=new Gtk::MenuItem("Key check");
+#	$smoe_keycheck->signal_connect('activate', \&Pronto::Crypt::GUI::keyserver_search_window);
+#	$smoe_keycheck->show();
+#	$smoe_menu->append($smoe_keycheck);
 	$smo_encrypt->set_submenu($smoe_menu);
 	$sm_options->set_submenu($smo_menu);
 	## the help menu
@@ -382,7 +383,7 @@ sub init_msg_window {
 	$lbl2->can_focus(0);
 	$msg_window->{'ToEntry'}->grab_focus;
  
-	$msg_window->{'encryptCheck'}->signal_connect('toggled', \&toggle_enc);
+	$msg_window->{'encryptCheck'}->signal_connect('toggled', \&toggle_enc, $msg_window);
 	$msg_window->{'signCheck'}->signal_connect('toggled', \&toggle_sign);
 	$toolbar->set_style($main::prefs{'toolbarstyle'});
 	if ($main::prefs{'toolbar'} eq "n") { $handlebox->hide; }
@@ -619,14 +620,12 @@ sub alias_expand {
 }
 
 sub toggle_enc {
- 
- 	if ($main::prefs{'Encrypt'}) {
-  		$main::prefs{'Encrypt'} = 0;
+ 	my ($button, $msg_window)=@_;
+ 	if ($msg_window->{'Encrypt'}) {
+  		$msg_window->{'Encrypt'} = 0;
  	} else {
-  		$main::prefs{'Encrypt'} = 1;
- 	}
- 	
-	&main::save_prefs();
+  		$msg_window->{'Encrypt'} = 1;
+ 	} 	
 }
 
 sub toggle_sign {
@@ -724,6 +723,9 @@ sub spellcheck {
  	$textbox=$msg_window->{'mailText'};
  	if(-f $main::prefs{'ispellpath'}) {
  		$Lingua::Ispell::path = $main::prefs{'ispellpath'};
+		if ($main::prefs{'dictionary'} && $main::prefs{'dictionary'} ne "") {
+			Lingua::Ispell::use_dictionary($main::prefs{'dictionary'});
+		}	
  	}
  	else {
 		&main::err_dialog(_("The path to ispell or aspell is not set correctly"));
