@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.17 2001/06/08 01:50:26 muhri Exp $
+# $Id: Config.pm,v 1.21 2002/05/19 06:20:46 muhri Exp $
 # -*- perl -*-
 package Pronto::Config;
 use strict;
@@ -75,6 +75,27 @@ sub init_send_config
 	$hbox->pack_start($label,0,0,0);
 	$vbox->pack_start($hbox,0,0,0);
 
+    	$hbox = new Gtk::HBox(0,5);
+    	$label = new Gtk::Label(_("Always forget my GPG/PGP passphrase?"));
+    	$label->set_alignment(0.0,0.5);
+    	$notebook->{'forget_passphrase'} = new Gtk::CheckButton();
+    	$notebook->{'forget_passphrase'}->set_active($main::prefs{'forget_passphrase'});
+    	$notebook->{'forget_passphrase'}->set_usize(16,17);
+    	$hbox->pack_start($notebook->{'forget_passphrase'},0,0,0);
+    	$hbox->pack_start($label,0,0,0);
+    	$vbox->pack_start($hbox,0,0,0);
+    
+	$label = new Gtk::Label(_("Use Dictionary: "));
+	$notebook->{'dictionary'} = new Gtk::Entry();
+	if ($main::prefs{'dictionary'}) { $notebook->{'dictionary'}->set_text($main::prefs{'dictionary'});}
+	$hbox = new Gtk::HBox(0,5);
+	$hbox->pack_start($label,0,0,0);
+	$label  = new Gtk::Label(_("Leave empty for default."));
+	$hbox->pack_start($notebook->{'dictionary'},0,0,0);
+	$hbox->pack_start($label,0,0,0);
+	$vbox->pack_start($hbox,0,0,0);
+	
+
 	$hbox = new Gtk::HBox(0,5);
 	$label = new Gtk::Label(_("Wrap after how many columns"));
 	$label->set_alignment(0.0,0.5);
@@ -776,6 +797,11 @@ sub init_web_browser_config
 	$hbox->pack_start($label,0,0,5);
 	$hbox->pack_start($notebook->{'ProxyPort'},0,0,5);
 	$vbox->pack_start($hbox,0,0,0);
+    
+    	$notebook->{'use_http_proxy'} = new Gtk::CheckButton(_("Pass my pop3 retrival / and SMTP sending via my http-proxy?"));
+	$notebook->{'use_http_proxy'}->set_active(1) if ($main::prefs{'use_http_proxy'});
+	$vbox->pack_start($notebook->{'use_http_proxy'},0,0,0);
+    
 
 	return $vbox;
 }
@@ -1088,7 +1114,7 @@ sub init_config {
 		
 	my ($main, $notebook);
 	my @node_names = (_("Send"), _("Receive"), _("View"), _("ToolBar"),
-			  _("Database"), _("Fonts"), _("Paths"), _("Web Browser"), 
+			  _("Database"), _("Fonts"), _("Paths"), _("Proxy"),
 			  _("Message Colors"), _("HTML"), _("Advanced"));
 	my @pages = (\&init_send_config, \&init_receive_config, \&init_view_config,
 		     \&init_toolbar_config,
@@ -1249,6 +1275,7 @@ sub update_conf {
 	$main::prefs{'MySQLPort'} = $notebook->{'MySQLPort'}->get_text if ($main::prefs{'DatabaseDriver'} eq "mysql");
 	$main::prefs{'PgSQLPort'} = $notebook->{'MySQLPort'}->get_text if ($main::prefs{'DatabaseDriver'} eq "Pg");
 	$main::prefs{'DateDisplayFormat'} = $notebook->{'DateDisplayFormat'}->get_text;
+	$main::prefs{'dictionary'} = $notebook->{'dictionary'}->get_text();
 	($main::prefs{'QuoteHeader'} = $notebook->{'QuoteHeader'}->get_chars(0,-1)) =~ s/\n/*n/g;
 	$main::prefs{'QuoteWith'} = $notebook->{'QuoteWith'}->get_text;
 	$main::prefs{'HomePage'} = $notebook->{'HomePage'}->get_text;
@@ -1285,6 +1312,7 @@ sub update_conf {
 	$main::prefs{'gpgpath'} = $notebook->{'gpgpath'}->get_text;
 	$main::prefs{'PrintCommand'} = $notebook->{'PrintCommand'}->get_text;
 	$main::prefs{'Proxy'} = $notebook->{'Proxy'}->get_text;
+        if ($notebook->{'use_http_proxy'}->active) { $main::prefs{'use_http_proxy'} = 1; } else { $main::prefs{'use_http_proxy'} = 0; }
 	$main::prefs{'ProxyPort'} = $notebook->{'ProxyPort'}->get_text;
 	$main::prefs{'SndCmd'} = $notebook->{'SndCmd'}->get_text;
 	$main::prefs{'SndFl'} = $notebook->{'SndFl'}->get_text;
@@ -1297,6 +1325,10 @@ sub update_conf {
 	$main::prefs{'MessageBgColor'} = $notebook->{'MessageBgColor'}->get_text;
 	$main::prefs{'startin'} = $notebook->{'startin'}->entry->get_text;
 	$main::prefs{'onfolderchange'} = $notebook->{'onfolderchange'}->entry->get_text;
+    if ($main::prefs{'forget_passphrase'} == 0 && $notebook->{'forget_passphrase'}->active()) {
+	&Pronto::Data::Message::forget_passphrase();
+    }
+    $main::prefs{'forget_passphrase'} = $notebook->{'forget_passphrase'}->active();
 	if($notebook->{'AutoCheckProgress'}->active) { $main::prefs{'AutoCheckProgress'} = 1 } else { $main::prefs{'AutoCheckProgress'} = 0 }
 	if ($notebook->{'Undo'}->active) { $main::prefs{'UndoEnabled'} = 1; } else { $main::prefs{'UndoEnabled'} = 0; }
 	if($notebook->{'RetRecAsk'}->active){$main::prefs{'SendReceipt'}='ask';}
