@@ -1,4 +1,4 @@
-# $Id: Message.pm,v 1.5 2001/06/08 01:50:27 muhri Exp $
+# $Id: Message.pm,v 1.13 2002/05/19 06:20:47 muhri Exp $
 # -*- perl -*-
 package Pronto::Data::Message;
 use Pronto::Crypt::GPG;
@@ -379,6 +379,27 @@ use Text::Wrap;
 
 my $gpg_object = new Pronto::Crypt::GPG();	## Create an object
 
+sub forget_passphrase
+{
+    $gpg_object->{'passphrase'} = undef;
+}    
+      
+sub verify
+{
+	if (-f $main::prefs{'gpgpath'}) {
+		$gpg_object->set_path($main::prefs{'gpgpath'});
+		return $gpg_object->verify($_[0]);
+	}	
+}	
+
+
+sub decrypt
+{
+	if (-f $main::prefs{'gpgpath'}) {
+		$gpg_object->set_path($main::prefs{'gpgpath'});
+		return $gpg_object->decrypt($_[0]);
+	}
+}	
 
 sub refilter 
 {
@@ -438,6 +459,7 @@ sub send_message {
 	my (@entry, $sql, $query, @row, $acctid, @attachments, $arrtmp, $tmp, $mimemail, $mimetype, $mimeencode, $defaultmime, $defaultenc, $ownkey, @keys);
 	$defaultmime="application/x-unknown";
 	$defaultenc="base64";
+
 	if (defined $msg_window){
 		$from = $msg_window->{'fromCombo'}->entry->get_text;
 		$sql = "select id, friendly, reply from accounts where descr=?";
@@ -480,29 +502,21 @@ sub send_message {
 		$subj=$psubject;
 		$body=$pbody;
 	}
-	$Text::Wrap::columns = $main::prefs{'WrapAfter'};
+	
+        $Text::Wrap::columns = $main::prefs{'WrapAfter'};
 	$body =~ s!(^[^>|+#}=):\%\@\$\?\r\n].*$)! &Text::Wrap::wrap("","",$1) !gem;
-	&main::wr_debug("New gpg object: $gpg_object");
-       	&main::wr_debug("Checking to see if message should be encrypted");
-	if (($main::prefs{'Encrypt'}) || ($main::prefs{'Sign'}) && (-f $main::prefs{'gpgpath'})) {
-		$gpg_object->set_path($main::prefs{'gpgpath'});
-		my $sth1 = $main::conn->prepare("select public_key from addresses where address=?");
-	 
-		$body = "\n".$body; ## For some reason the first line is lost
-		if ($main::prefs{'Encrypt'}) {
-			&main::wr_debug("This mail should be encrypted");
-			&main::wr_debug("Obtaining a list of EMail addresses");
 
+	if (((defined $msg_window && $msg_window->{'Encrypt'} == 1) || ($main::prefs{'Sign'})) && (-f $main::prefs{'gpgpath'})) {
+		$gpg_object->set_path($main::prefs{'gpgpath'});
+		my $sth1 = $main::conn->prepare("select public_key from addresses where address=?");	 
+		$body = "\n".$body; ## For some reason the first line is lost
+		if (defined $msg_window && $msg_window->{'Encrypt'}) {
 			my @email_addresses;
 			push(@email_addresses, $gpg_object->get_addresses_from_string($to));
 			push(@email_addresses, $gpg_object->get_addresses_from_string($cc));
 			if ($main::prefs{'EncToSelf'}) {
 				push(@email_addresses, $gpg_object->get_addresses_from_string($from));
 			}
-
-			&main::wr_debug("EMails: @email_addresses");
-			&main::wr_debug("Mail to be signed from: $from");
-			&main::wr_debug("Checking each address for a coresponding PGP key");
 	 
 			foreach my $check_email (@email_addresses) {
 				$sth1->execute($check_email);
@@ -511,8 +525,7 @@ sub send_message {
 				my $key = $raw_return[0];
 	
 				if (not defined $key) {
-					&main::wr_debug("No key specified in Addressbook - I got: $key");
-					&main::err_dialog(_("No key specified in addressbook for\n$check_email.\nOpen Addressbook and specify the key there."));
+					&main::err_dialog(_("No key specified in addressbook for\n$check_email.\nOpen Addressbook and specify the key there."),"y");
 					return 1;
 				} else {
 					push(@keys, $key);
@@ -524,39 +537,42 @@ sub send_message {
 		if ($main::prefs{'Sign'}) {
 			$sth1->execute($gpg_object->get_addresses_from_string($from));
 			$ownkey = $sth1->fetchrow_array;
-
 			if (not defined $ownkey) {
-				&main::wr_debug("No key specified for myself - I cant sign");
-				&main::err_dialog(_("I dont have a key specified for myself - No signing available"));
+				&main::err_dialog(_("I dont have a key specified for myself - No signing available"),"y");
+				return 1;
 			}
 		}
 
-		&main::wr_debug("Keys: @keys");
-
-		my ($stdout, $sterr) = $gpg_object->encrypt(\@keys, [$body],$main::prefs{'Encrypt'}, $main::prefs{'Sign'}, $ownkey);
-
-		&main::wr_debug("STDOUT: $stdout");
-		&main::wr_debug("STERR: $sterr");
-
-		if (($stdout eq undef) || (grep(/BAD_PASSPHRASE/, @$sterr))) {
-			&main::wr_debug("Unable to encrypt - Raise errorbox");
-			&main::err_dialog(_("Encryption did not complete with the following errors: .")."\n @$sterr");
-
-			if ($main::prefs{'Sign'}) {
-				&main::wr_debug("OPening obtain_passphrase");
-				$gpg_object->obtain_passphrase();
-			}
+	        my $encryptFlag=0;
+	        if (defined $msg_window && $msg_window->{'Encrypt'} == 1) {
+		    $encryptFlag = 1;
+		} 
+		my ($stdout, $sterr) = $gpg_object->encrypt(\@keys, [$body],$encryptFlag, $main::prefs{'Sign'}, $ownkey);
 
+		if (!$stdout) {
+			&main::err_dialog(_("Encryption did not complete with the following errors: .")."\n @$sterr","y");
 			return 1;
-		}
+		}			
 
-		&main::wr_debug("STDOUT2: @$stdout");
+		if (grep(/BAD_PASSPHRASE/, @$sterr)) {
+			&main::err_dialog(_("Appearntly you entered a bad passphrase for your key $ownkey\n@$sterr\nEnter it again then retry sending"),"y");
+			$gpg_object->{'passphrase'} = undef;
+			$gpg_object->obtain_passphrase();
+			return 1;1
+		}
+		
 		$body = join('', @$stdout);
 
-		&main::wr_debug("BODY: $body");
+		if (!$body) { 
+			&main::err_dialog(_("Something went wrong during encrypt/sign!\n@$sterr"),"y");
+			return 1; 
+	       	}
+
+	} elsif (((defined $msg_window && $msg_window->{'Encrypt'}) || ($main::prefs{'Sign'})) && !-f $main::prefs{'gpgpath'}) {
+	    &main::err_dialog(_("You have selected to either encrypt or sign the message, however the gpg path is not set correctly. Please correct it from Pronto's options"), "y");
+	    return 1;
+	}    
 
-	}
- 
 	my $date = &main::date_now;
 	my $localdate = &main::date_to_localdate($date);
 	my $msgid = scalar(localtime) . "\@$from";
@@ -573,13 +589,16 @@ sub send_message {
 					Type=>"text/plain",
 					Charset=>$main::prefs{'CharSet'},
 					Encoding=>'-SUGGEST',
-					Date=>&main::UnixDate(&main::ParseDateString("epoch ".time()),"%d %b %Y %H:%M:%S %Z"),
+#					Date=>&main::UnixDate(&main::ParseDateString("epoch ".time()),"%d %b %Y %H:%M:%S %Z"),
+#Remco Lubbers <rpl@wanadoo.nl> said the above line is not RFC822 cmpliant
+					Date=>&main::UnixDate(&main::ParseDateString("epoch ".time()),"%a, %e %b %Y %H:%M:%S %z"),
 					Data=>$body);
 	
 	$mimemail->head->add('Reply-To',$from) if ($main::prefs{'IncludeReplyTo'});
 	
 	# check if a reciept is requested
-	if (defined $msg_window && $msg_window->{'receiptCheck'}->active){
+
+	if ((defined $msg_window) && ($msg_window->{'receiptCheck'}->active)){
 		my $frommail=$from;
 		$frommail=~s/(.+) \<(.+)\>/\<$2\>/;
  		$mimemail->head->add('Disposition-Notification-To',$frommail);
@@ -603,7 +622,7 @@ sub send_message {
 	# check if priority is not normal, then set the header field
 	my @priolist=("1 (Highest)","2 (High)","3 (Normal)","4 (Low)","5 (Lowest)");
 	my $priority = $priolist[3];
-	if (defined $msg_window && !$msg_window->{'priorityRadio'}[2]->active){
+	if ((defined $msg_window) && (!$msg_window->{'priorityRadio'}[2]->active)){
 		my $tmp;
 		for ($tmp=0;$tmp<scalar(@priolist);$tmp++){
 			last if ($msg_window->{'priorityRadio'}[$tmp]->active);
