@@ -1,4 +1,4 @@
-# $Id: FolderTree.pm,v 1.9 2001/08/22 09:37:42 muhri Exp $
+# $Id: FolderTree.pm,v 1.10 2002/05/14 08:36:11 muhri Exp $
 # -*- perl -*-
 package Pronto::FolderTree;
 use strict;
@@ -357,7 +357,7 @@ sub new_folder {
 	my ($virtual,$querycontent,$body) = @_;
   	my ($fldr_dlg, $fd_hbox, $fd_label, $fd_button, $fd_ok, $fd_entry,
       	$fldr_ctree, $fldr_scroll, $fd_label2, %lparent, @nf_node, $sql,
-      	$query, %lft_id, @row, $title,$selected);
+      	$query, %lft_id, @row, $title,$selected,$selected_node);
   	my @fldr_sel = $main::folder_tree->selection;
   	if (@fldr_sel) { $selected = $main::ft_id{$fldr_sel[0]} }
   	$fldr_dlg = new Gtk::Dialog;
@@ -399,9 +399,13 @@ sub new_folder {
     			$nf_node[$row[1]] = $fldr_ctree->insert_node($nf_node[$row[3]],$nf_node[$row[2]],$title,5,undef,undef,undef,undef,0,1);
    		}
    		$lft_id{$nf_node[$row[1]]} = $row[1];
-  		if (@fldr_sel && $selected == $row[1]) { $selected = $nf_node[$row[1]] }
-  	}
-  	if (@fldr_sel) { $fldr_ctree->select($selected); }
+  		if (@fldr_sel && $selected == $row[1]) {
+			$selected_node = $nf_node[$row[1]]; 	
+  		}
+ 	}
+	
+ 	if (@fldr_sel) { $fldr_ctree->select($selected_node); }
+		
   	$fldr_ctree->show;
   	$fldr_scroll = new Gtk::ScrolledWindow(undef,undef);
   	$fldr_scroll->set_policy('automatic', 'automatic');
@@ -424,9 +428,9 @@ sub new_folder {
    			$fldr_dlg, $fldr_ctree, \%lft_id, $virtual, $querycontent,$body);
    		} else {
   		$fd_ok->signal_connect("clicked" => \&add_new_folder, $fd_entry,
-     			$fldr_dlg, $fldr_ctree, \%lft_id);
+     			$fldr_dlg, $fldr_ctree, \%lft_id, undef, undef, undef,$selected);
   		$fd_entry->signal_connect("activate" => \&add_new_folder, $fd_entry,
-     			$fldr_dlg, $fldr_ctree, \%lft_id);
+     			$fldr_dlg, $fldr_ctree, \%lft_id, undef, undef, undef, $selected);
   		}
   	$fldr_dlg->signal_connect("size-request" => \&main::save_win_size, "fldrdlg", $fldr_dlg->window);
 	$fd_entry->grab_focus();  	
@@ -687,7 +691,7 @@ sub delete_folder {
 
 sub add_new_folder {
 	
-	my ($widget, $entry, $win, $fldr_ctree, $ftidref,$virtual,$querycontent,$body) = @_;
+	my ($widget, $entry, $win, $fldr_ctree, $ftidref,$virtual,$querycontent,$body,$daddy) = @_;
 	my ($nfparent, $foldername, @sel, %lft_id);
 	$foldername = $entry->get_text;
 	if ($foldername eq '') { &main::err_dialog(_("Enter a name first !")); return 1; }
@@ -699,12 +703,18 @@ sub add_new_folder {
 	}
 
 	%lft_id = %{$ftidref};
+
  	@sel = $fldr_ctree->selection();
  	if (@sel) {
-  		$nfparent = $lft_id{$sel[0]};
+  		$nfparent = $daddy;
+		if (!$nfparent) { 
+			print(_("couldn't get parent for new folder, creating under the root\n"));
+			$nfparent = 0;
+	       	}
  	} else {
   		$nfparent = 0;
  	}
+	
  	$win->destroy;	
 	my ($sql, $query, $sort, $id);
  	$sql="select id from boxlist where ((parent = ?) and (sibling = 65535))";
