@@ -1,4 +1,4 @@
-# $Id: Get.pm,v 1.11 2001/06/11 01:57:08 muhri Exp $
+# $Id: Get.pm,v 1.14 2002/04/11 07:46:02 muhri Exp $
 # -*- perl -*- 
 package Pronto::Get;
 use strict;
@@ -92,16 +92,18 @@ sub get_pop3
        	if (defined $status_dialog) {
        		while (events_pending Gtk) { main_iteration Gtk; }
       	}	
-       	unless (@test = gethostbyname($account->{'srvr'})){
-       		if ($inter == 1) {
-       			&main::err_dialog(_("Mail Host Not Found:") . "\n\n$account->{'srvr'}", "y", _("POP3 Connect Error"));
-       		} else {
-       			print(_("Mail host not found: ") . "$account->{'srvr'}\n");
-       		}	
-       		return;
-       	}
-       	if (defined $status_dialog) {
-       		$status_dialog->{'statuslabel'}->set_text(_("Checking account ") . $account->{'desc'});
+	if (!$main::prefs{'use_http_proxy'}) {
+		unless (@test = gethostbyname($account->{'srvr'})){
+			if ($inter == 1) {
+				&main::err_dialog(_("Mail Host Not Found:") . "\n\n$account->{'srvr'}", "y", _("POP3 Connect Error"));
+			} else {
+				print(_("Mail host not found: ") . "$account->{'srvr'}\n");
+			}	
+			return;
+		}
+	}
+	if (defined $status_dialog) {
+		$status_dialog->{'statuslabel'}->set_text(_("Checking account ") . $account->{'desc'});
        		$percent = 0;
        		$status_dialog->{'progressbar'}->set_value($percent);
        		$status_dialog->{'mailprogressbar'}->set_value($percent);
@@ -113,14 +115,37 @@ sub get_pop3
        	if (defined $status_dialog) {
        		while (events_pending Gtk) { main_iteration Gtk; }
 	}	
+    
+	if (!$main::prefs{'use_http_proxy'}) {
+		$socket = IO::Socket::INET->new(PeerAddr => "$account->{'srvr'}", PeerPort => "$account->{'port'}", Proto => "tcp", Type => SOCK_STREAM) or return;
+	} else {
+	
+		$socket = IO::Socket::INET->new(PeerAddr => $main::prefs{'Proxy'}, PeerPort => $main::prefs{'ProxyPort'}, Proto => "tcp", Type => SOCK_STREAM) or return; #die "Couldn't create socket $!\n";
+		print $socket "connect $account->{'srvr'}:$account->{'port'} http/1.0\r\n\r\n";
+		#    $answer = <$socket>;
+		my $string = <$socket>;
+		chomp($string);
+		my ($proxy_status) = (split (/ /, $string))[1];
+	        if (int ($proxy_status / 100) != 2) {
+		    if ($inter == 1) {
+			   &main::err_dialog(_("Recieved bad status code \"$proxy_status\" from http-proxy while connecting to $account->{'srvr'}:$account->{'port'}"),"y",_("POP 3 Connect Error"));
+		    } else {
+			   print("Recieved bad status code \"$proxy_status\" from http-proxy while connecting to $account->{'srvr'}:$account->{'port'}\n");
+		    }
+		    return;
+	        }
+		my $test_int=0;
+		while (!$test_int) {
+			$string = <$socket>;
+			if ($string eq "\n") { $test_int = 1; }
+		}
+	}
+    
+	$answer = <$socket>;		
 
-	$socket = IO::Socket::INET->new(PeerAddr => "$account->{'srvr'}", PeerPort => "$account->{'port'}", Proto => "tcp", Type => SOCK_STREAM) or return;
-
-       	$answer = <$socket>;		
-
-       	if (defined $status_dialog) {
+	if (defined $status_dialog) {
 		while (events_pending Gtk) { main_iteration Gtk; }
-       	}		
+	}		
 
        	# Need two things for APop to work
 
@@ -175,6 +200,7 @@ sub get_pop3
 		}		
 	
        		$answer = <$socket>;
+
        		if ($answer !~ /^\+OK/){ 
 			if ($inter == 1) {
        		       		&main::err_dialog(_("Server \"") . $account->{'srvr'} . "\" said:\n\n" . $answer, "y", _("POP3 Connect Error"));
