@@ -1,4 +1,4 @@
-# $Id: MainWindow.pm,v 1.16 2001/07/24 11:26:07 muhri Exp $
+# $Id: MainWindow.pm,v 1.17 2002/05/16 12:00:50 muhri Exp $
 # -*- perl -*-
 package Pronto::MainWindow;
 use strict;
@@ -482,7 +482,21 @@ sub init_main_window {
  	$mm_delete->signal_connect("activate" => \&Pronto::MainWindow::handle_delete_msgs);
  	$accel_group->add( $key_hash{'Delete'}, $mod{$key_hash{'Delete'.'mod'}},['visible'], $mm_delete, "activate"); 
  	$message_menu->append($mm_delete);
- 	
+	
+	my $encryption_menu = new Gtk::Menu;
+	$encryption_menu->{'verify'} = new Gtk::MenuItem(_("Verify Signature"));
+	$encryption_menu->{'verify'}->signal_connect("activate" => \&Pronto::Data::MessageOp::verify);
+	$accel_group->add( $key_hash{'Verify'}, $mod{$key_hash{'Verify'.'mod'}} ,['visible'], $encryption_menu->{'verify'}, "activate");
+	$encryption_menu->{'decrypt'} = new Gtk::MenuItem(_("Decrypt Message"));
+	$accel_group->add( $key_hash{'Decrypt'}, $mod{$key_hash{'Decrypt'.'mod'}} ,['visible'], $encryption_menu->{'decrypt'}, "activate");
+	$encryption_menu->{'decrypt'}->signal_connect("activate" => \&Pronto::Data::MessageOp::decrypt);
+	
+	$encryption_menu->append($encryption_menu->{'verify'});
+	$encryption_menu->append($encryption_menu->{'decrypt'});
+	my $mm_encryption = new Gtk::MenuItem(_("Encryption"));
+	$mm_encryption->set_submenu($encryption_menu);
+	$message_menu->append($mm_encryption);
+	
 	my $serverstatmenu = new Gtk::Menu;
 	
 	$serverstatmenu->{'ServerLeave'} = new Gtk::MenuItem(_("Leave on server"));
