@@ -1,4 +1,4 @@
-# $Id: TableEdit.pm,v 1.2 2001/02/03 16:22:54 muhri Exp $
+# $Id: TableEdit.pm,v 1.4 2002/05/19 07:23:35 muhri Exp $
 # -*- perl -*-
 package Pronto::TableEdit;
 use strict;
@@ -185,7 +185,7 @@ sub acct_editwin {
  	
 	my ($aw_cancel, $aw_ok, $action, $mainid, @entry, @cbut, $aw_dlg, $i, @hbox,
       	$name, @en_val, @cb_val, @sig, $acct_clist, @label, $aw_sig, $sig_scroll,
-      	$sig_hbox, $sig_label, @ent_labels, $c_type, $c_hbox, $c_label, $account_type, @ent_label);
+      	$sig_hbox, @ent_labels, $c_type, $c_hbox, $c_label, $account_type, @ent_label);
   	$action = $_[1];
   	$mainid = $_[2];
   	$acct_clist = $_[3];
@@ -218,12 +218,14 @@ sub acct_editwin {
   	$aw_dlg->set_title(_("Account Editor"));
   	$aw_dlg->position(-mouse);
   	$aw_dlg->border_width(0);
+	$aw_dlg->{'notebook'} = new Gtk::Notebook();
+	my $vbox = new Gtk::VBox(0,5);    
   	$i = 0;
 
   	$c_hbox = new Gtk::HBox(0,0);
   	$c_hbox->border_width(5);
   	$c_label = new Gtk::Label(_("Account Type:"));
-  	$c_label->set_usize(100,10);
+  	$c_label->set_usize(120,10);
   	$c_label->set_alignment(0.5,0.5);
   	$c_type = new Gtk::Combo;
   	$c_type->set_case_sensitive('0');
@@ -235,16 +237,17 @@ sub acct_editwin {
  	$c_hbox->pack_start($c_type,1,1,0);
   	$c_hbox->show;
   	$c_label->show;
-  	$aw_dlg->vbox->pack_start($c_hbox,1,1,0);
-
+  	$vbox->pack_start($c_hbox,1,1,0);
+	$aw_dlg->vbox->pack_start($aw_dlg->{'notebook'},1,1,0);
+	$vbox->show;
   	foreach $name (@ent_labels) {
    		$hbox[$i]=new Gtk::HBox(0,0);
    		$hbox[$i]->border_width(5);
-   		$aw_dlg->vbox->pack_start($hbox[$i],1,1,0);
+   		$vbox->pack_start($hbox[$i],1,1,0);
    		$hbox[$i]->show;
    		$ent_label[$i]=new Gtk::Label "$name ";
    		$ent_label[$i]->set_alignment(0.5,0.5);
-   		$ent_label[$i]->set_usize(100,10);
+   		$ent_label[$i]->set_usize(120,10);
    		$hbox[$i]->pack_start($ent_label[$i],0,1,0);
    		$ent_label[$i]->show;
    		$entry[$i]=new Gtk::Entry;
@@ -265,7 +268,7 @@ sub acct_editwin {
        		$hbox[7]->hide;
   	}
   	$i = 0;
-  	
+  	my $vbox2 = new Gtk::VBox(0,0);
 	foreach $name (@buttons) {
    		my $hbox;
    		$cbut[$i] = new_with_label Gtk::CheckButton("$name");
@@ -275,11 +278,11 @@ sub acct_editwin {
    		$hbox->border_width(3);
    		$hbox->pack_start($cbut[$i],1,1,0);
    		$hbox->show;
-   		$aw_dlg->vbox->pack_start($hbox,1,1,0);
+   		$vbox2->pack_start($hbox,1,1,0);
    		$i++;
   	}
-  	$sig_label = new Gtk::Label (_("Signature:"));
-  	$sig_label->show;
+	$vbox2->show;
+	my $vbox3 = new Gtk::VBox(0,0);
   	$aw_sig=new Gtk::Text(undef,undef);
   	$aw_sig->set_word_wrap(1);
   	$aw_sig->set_editable('1');
@@ -296,8 +299,12 @@ sub acct_editwin {
   	$sig_hbox->pack_start($aw_sig,1,1,0);
   	$sig_hbox->pack_start($sig_scroll,0,0,0);
   	$sig_hbox->show;
-  	$aw_dlg->vbox->pack_start($sig_label,0,0,0);
-  	$aw_dlg->vbox->pack_start($sig_hbox,1,1,0);
+  	$vbox3->pack_start($sig_hbox,1,1,0);
+	$vbox3->show;
+	$aw_dlg->{'notebook'}->append_page($vbox, new Gtk::Label(_("Info")));
+	$aw_dlg->{'notebook'}->append_page($vbox2, new Gtk::Label(_("Options")));
+	$aw_dlg->{'notebook'}->append_page($vbox3, new Gtk::Label(_("Signature")));
+	$aw_dlg->{'notebook'}->show;
   	$aw_ok=new Gtk::Button _("Ok");
   	$aw_ok->signal_connect("clicked" => \&update_accounts, $action,
         $mainid, $aw_dlg, $acct_clist, \@entry, \@cbut, $aw_sig, $c_type);
@@ -411,7 +418,7 @@ sub update_filters {
 		$query->execute($type, $boxid, $regex, $addr, $name,$cb_regex->active, $count, $fltid);
 	}
 	if ($action ne "newfromlist") {
-	&clist_refresh($filter_clist);
+		&clist_refresh($filter_clist); 
 	}
 	$fw_dlg->destroy;
 	if ($apply->active) { &Pronto::Data::Message::refilter }
