@@ -1,12 +1,12 @@
 #!/usr/bin/perl -w # Yeah baby YEAH!!!!!!!!!!! muhri@muhri.net # for Liki.
-# $Id: ProntoInstaller.pl,v 1.6 2001/08/15 18:59:49 muhri Exp $
+# $Id: ProntoInstaller.pl,v 1.11 2002/05/25 00:37:37 muhri Exp $
 #############################################################################
                                                                    	    #
   	mkdir("$ENV{'HOME'}/prontobuild", 0755);                            #
   	$builddir = "$ENV{'HOME'}/prontobuild";                             #
   	$untar = "tar xvzf";                                                #
-  	$mirror = "http://download.sourceforge.net/mirrors/CPAN/authors/id";#
-  	$prontoversion = "2.2.6";                                           #
+  	$mirror = "http://www.cpan.org/authors/id";                         #
+  	$prontoversion = "2.4.0";                                           #
   	$getcmd = $ARGV[0];                                                 #
   	$compile = "perl Makefile.PL ; make ; make install";                #
   	$cyberdeck = "http://www.muhri.net/pronto";                         #
@@ -1627,18 +1627,18 @@ sub go {
   		$newgtk = 0; &checkforxmhtml("$newgtk"); 
 	}
 
-  	&check("Date::Manip","SBECK","DateManip-5.39.tar.gz","DateManip-5.39",5.39);
+  	&check("Date::Manip","SBECK","DateManip-5.40.tar.gz","DateManip-5.40",5.39);
   	&check("DBI","TIMB","DBI-1.14.tar.gz","DBI-1.14",1.14);
   	&check("Text::CSV_XS","JWIED","Text-CSV_XS-0.20.tar.gz","Text-CSV_XS-0.20",0.20);
   	&check("SQL::Statement","JWIED","SQL-Statement-0.1016.tar.gz","SQL-Statement-0.1016",0.1016);
-  	&check("DBD::CSV","JWIED","DBD-CSV-0.1022.tar.gz","DBD-CSV-0.1022",0.1022);
+  	&check("DBD::CSV","JWIED","DBD-CSV-0.1030.tar.gz","DBD-CSV-0.1030",0.1022);
   	&check("MIME::Base64","GAAS","MIME-Base64-2.12.tar.gz","MIME-Base64-2.12",2.11);
-  	&check("HTML::Parser","GAAS","HTML-Parser-3.15.tar.gz","HTML-Parser-3.15",3.08);
-  	&check("IO::Wrap","ERYQ","IO-stringy-1.213.tar.gz","IO-stringy-1.213",1.104);
-  	&check("MIME::Parser","ERYQ","MIME-tools-5.314.tar.gz","MIME-tools-5.314",5);
+  	&check("HTML::Parser","GAAS","HTML-Parser-3.26.tar.gz","HTML-Parser-3.26",3.08);
+  	&check("IO::Wrap","ERYQ","IO-stringy-2.108.tar.gz","IO-stringy-2.108",1.2);
+  	&check("MIME::Parser","ERYQ","MIME-tools-5.411a.tar.gz","MIME-tools-5.411",5);
   	&check("Mail::Header","GBARR","MailTools-1.1401.tar.gz","MailTools-1.1401",1.14);
   	&check("MIME::Types","O/OK/OKAMOTO","MIME-Types-0.02.tar.gz","MIME-Types-0.02",0.02);
-  	&check("URI::URL","GAAS","URI-1.09.tar.gz","URI-1.09",5);
+  	&check("URI::URL","GAAS","URI-1.19.tar.gz","URI-1.19",5);
   	&check("IO::Socket","GBARR","IO-1.20.tar.gz","IO-1.20",1.20);
   	&check("Lingua::Ispell","J/JD/JDPORTER","Lingua-Ispell-0.07.tar.gz","Lingua-Ispell-0.07",0.07);
   	$status_dialog->{'statuslabel'}->set_text("Waiting for user Input");
