@@ -1,4 +1,4 @@
-## $Id: prontolib.pl,v 1.18 2001/07/13 08:39:26 muhri Exp $
+## $Id: prontolib.pl,v 1.23 2002/05/21 00:46:32 muhri Exp $
 use vars qw( %prefs $libpath $locale $locale_installed);
 use strict;
 use DBI;
@@ -45,7 +45,7 @@ $prefs{'AddReplytoAB'}="n";
 $prefs{'SortCol'} = '6';
 $prefs{'SortDir'} = "ascending";
 $prefs{'SendImmediately'}="y";
-$prefs{'ForwardAttachments'} = "n";
+$prefs{'ForwardAttachments'} = "y";
 $prefs{'FolderNewBold'}="y";
 $prefs{'InlineImages'}="y";
 $prefs{'InlineAttachments'}="y";
@@ -138,6 +138,7 @@ $prefs{'autosave'} = 1;
 $prefs{'FTDetached'} = 0;
 $prefs{'ToolTips'} = 1;
 $prefs{'AddybookSort'} = 0;
+$prefs{'use_http_proxy'} = 0; #get pop3 via http_proxy?  
 #toolbar buttons
 $prefs{'ButtonSAndR'} = 1;
 $prefs{'ButtonNew'} = 1;
@@ -147,6 +148,8 @@ $prefs{'ButtonForward'} = 1;
 $prefs{'ButtonDelete'} = 1;
 $prefs{'ButtonAddyBook'} = 1;
 $prefs{'UndoEnabled'} = 0;
+$prefs{'dictionary'} = "";
+$prefs{'forget_passphrase'} = 1;
 ## End Default Prefs.
 
 sub numerically { $a <=> $b; }
@@ -656,7 +659,7 @@ sub save_message
 	if ($newsentfrom) {$sentfrom = $newsentfrom;}
 	if ($newcc) {$cc = $newcc;}
 	if ($newreplyto) {$replyto = $newreplyto;}
-	
+	if ($newsentto) { $sentto=$newsentto;}	
 	# some fields can be huge, e.g. sentto, and dbd:csv will not truncate them 
 	# most real sql databases will truncate quietly to the size of varchar
 	if ($prefs{'DatabaseDriver'} eq "CSV") {
@@ -670,7 +673,7 @@ sub save_message
 				values 
 			(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?,?,?)";
 		$query2=$conn->prepare($sql2);	
-		$query2->execute($newid, $msgid, $boxid, $account->{'id'}, $date, $sentto, $sentfrom, $subject, $contenttype, $contentxferencode, $mimeversion, $precedence, $approvedby, $inreplyto, $replyto, $listsub, $listunsub, $status, $xorigip, $cc, $sender, $returnpath, $priority, $xmailer, $xuidl, $xsender, $localdate, $isnew, $sf_friendly, $receiptto, $score,$ref,$serverstat) or return undef;	
+		$query2->execute($newid, $msgid, $boxid, $account->{'id'}, $date, $sentto, $sentfrom, $subject, $contenttype, $contentxferencode, $mimeversion, $precedence, $approvedby, $inreplyto, $replyto, $listsub, $listunsub, $status, $xorigip, $cc, $sender, $returnpath, $priority, $xmailer, $xuidl, $xsender, $localdate, $isnew, $sf_friendly, $receiptto, $score,$ref,$serverstat) or return undef;
 		$tmp = filename_to_tree("$prefs{'MailDir'}/$newid", 1);
 		wr_debug("Message file to be opened is: $tmp");
 		open (TMP,">$tmp") or return undef;
@@ -686,7 +689,7 @@ sub save_message
 		$query2->execute($newid, $msgid, $boxid, $account->{'id'}, $date, $sentto, $sentfrom, $subject, $contenttype, $contentxferencode, $mimeversion, $precedence, $approvedby, $inreplyto, $replyto, $listsub, $listunsub, $status, $xorigip, $cc, $sender, $returnpath, $priority, $xmailer, $xuidl, $xsender, $localdate, $isnew, $sf_friendly, $receiptto, $score,$ref,$serverstat) or return undef;
 		$sql2 = "insert into message_sources (id,bodytext) values (?,?)";
 		$query2=$conn->prepare($sql2);
-		$query2->execute($newid, $rawbody);
+		$query2->execute($newid, $rawbody) or return undef;
 		return "success";
 	}	
 	
